mobspy.parameters package — MobsPy 2.2 documentation

# mobspy.parameters package

## Submodules

## mobspy.parameters.default_reader module

This model is responsible for storing MobsPy default parameters

mobspy.parameters.default_reader.get_default_parameters()

## mobspy.parameters.example_reader module

This model is responsible for storing example parameters It’s used by the simulation to check which parameters exist or not. If a new parameter is added, they key must be added here as an example. Otherwise the simulation object will throw a compilation error, telling the user that the parameter is not supported,

mobspy.parameters.example_reader.get_example_parameters()

## Module contents